<!-- $Revision: 7202 $ -->
<HTML>
  <HEAD>
    <TITLE>Listi <MM-List-Name> info</TITLE>
  
  </HEAD>
  <BODY BGCOLOR="#ffffff">

    <P>
      <TABLE COLS="1" BORDER="0" CELLSPACING="4" CELLPADDING="5">
	<TR>
	  <TD COLSPAN="2" WIDTH="100%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	    <B><FONT COLOR="#000000" SIZE="+1"><MM-List-Name> --
	<MM-List-Description></FONT></B>
	  </TD>
	</TR>
	<tr>
	    <td colspan="2">
	      <p>&nbsp;
	    </td>
	  </tr>
	  <tr>
	    <TD COLSPAN="1" WIDTH="100%" BGCOLOR="#FFF0D0">
	      <B><FONT COLOR="#000000"><MM-List-Name> listi info</FONT></B>
	    </TD>
            <TD COLSPAN="1" WIDTH="100%" BGCOLOR="#FFF0D0">
              <MM-lang-form-start><MM-displang-box> <MM-list-langs>
              <MM-form-end>
    <MM-Subscribe-Form-Start>
            </TD>
	  </TR>
	    <tr>
	      <td colspan="2">
		<P><MM-List-Info></P>
	  <p> <MM-Archive><MM-List-Name> arhiiv</MM-Archive>.
	      <MM-Restricted-List-Message>
	  </p>
	</TD>
      </TR>
      <TR>
	<TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	  <B><FONT COLOR="#000000"><MM-List-Name> kasutamine</FONT></B>
	</TD>
      </TR>
      <tr>
	<td colspan="2">
	 Listi kirjutamiseks on aadress
	  <A HREF="mailto:<MM-Posting-Addr>"><MM-Posting-Addr></A>.
	  <p>Listi saab tellida ja tellimuse profiili muuta allpool</p>
	</td>
      </tr>
      <TR>
	<TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	  <B><FONT COLOR="#000000"><MM-List-Name> listi tellimine</FONT></B>
	</TD>
      </TR>
      <tr>
	<td colspan="2">
	  <P>
	   <MM-List-Name> tellimiseks täitke järgnev vorm
	  <MM-List-Subscription-Msg>
	  <ul>
	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
		WIDTH="70%" HEIGHT= "112">
		<TR>
		  <TD BGCOLOR="#dddddd" WIDTH="55%">E-posti aadress:</TD>
		  <TD WIDTH="33%"><MM-Subscribe-Box>
	</TD>
	<TD WIDTH="12%">&nbsp;</TD></TR>
      <tr>
        <td bgcolor="#dddddd" width="55%">Nimi (võib ka tühjaks jätta):</td>
        <td width="33%"><mm-fullname-box></td>
	<TD WIDTH="12%">&nbsp;</TD></TR>
      <TR>
	<TD COLSPAN="3"><FONT SIZE=-1>Allpool olevasse vormi saab
	    sisestada parooli. See pole just üleliia turvaline,
	    kuid peaks ära hoidma selle, et keegi teine teie tellimust
	    muutma pääseb. <b>Ärge sisestage parooli, mida mujal kasutate</b>,
	    sest see parool saadetakse teile meiliga.

	    <p>Kui te parooli ei sisesta, siis genereeritakse see automaatselt
	    ning saadetakse teile niipea, kui olete oma tellimuse kinnitanud.
	    Hiljem on võimalik tellida automaatne parooli meeldetuletus.
	    <MM-Reminder>
	    </p>
	</TD>
      </TR>  
      <TR>
	<TD BGCOLOR="#dddddd">Parool:</TD>
	<TD><MM-New-Password-Box></TD>
	<TD>&nbsp;</TD></TR>
      <TR> 
	<TD BGCOLOR="#dddddd">Parool uuesti:</TD>
	<TD><MM-Confirm-Password></TD>
	<TD>&nbsp; </TD></TR>
      <tr>
        <TD BGCOLOR="#dddddd">Kasutajaliidese keel?</TD> 
        <TD> <MM-list-langs></TD>
        <TD>&nbsp; </TD></TR>
      <tr>
	<td>Kirju saadetakse kokkuvõtetena
	  </td>
	<td><MM-Undigest-Radio-Button> Ei
	    <MM-Digest-Radio-Button>  Jah
	</TD>
      </tr>
      <tr>
	<td colspan="3">
	  <center><MM-Subscribe-Button></P></center>
    </TABLE>
    <MM-Form-End>
    </ul>
    </td>
    </tr>
    <TR>
      <TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	<a name="subscribers">
        <B><FONT COLOR="#000000"><MM-List-Name> tellijad</FONT></B></a>
      </TD>
    </TR>
    <tr>
      <TD COLSPAN="2" WIDTH="100%">
	<MM-Roster-Form-Start>
	<MM-Roster-Option>
	    <MM-Form-End>
	  <p>
	<MM-Options-Form-Start>
	<MM-Editing-Options>
		<MM-Form-End>
      </td>
    </tr>
  </table>
<MM-Mailman-Footer>
</BODY>
</HTML>
