<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 3.2//EN">
<HTML>
  <HEAD>
     <title> %(listname)s 邮件归档</title>
     <META NAME="robots" CONTENT="noindex,follow">
     %(meta)s
  </HEAD>
  <BODY BGCOLOR="#ffffff">
     <h1>%(listname)s 邮件归档</h1>
     <p>
      你可以获得关于<a href="%(listinfo)s">这个列表的更多信息</a>
      或者<a href="%(fullarch)s">下载完整的原始归档文件</a>
      (%(size)s).
     </p>
     %(noarchive_msg)s
     %(archive_listing_start)s
     %(archive_listing)s
     %(archive_listing_end)s
     </BODY>
     </HTML>
