<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 3.2//EN">
<HTML>
  <HEAD>
     <title>Arkiv f&ouml;r %(listname)s </title>
     <META NAME="robots" CONTENT="noindex,follow">
     %(meta)s
  </HEAD>
  <BODY BGCOLOR="#ffffff">
     <h1>Arkiv f&ouml;r %(listname)s  </h1>
     <p>
      Du kan f&aring; <a href="%(listinfo)s">mer information om denna lista</a> eller
     s&aring; kan du <a href="%(fullarch)s">ladda ner det kompletta arkivet</a>
      (%(size)s).
     </p>
     %(noarchive_msg)s
     %(archive_listing_start)s
     %(archive_listing)s
     %(archive_listing_end)s
     </BODY>
     </HTML>
